'''
Defines the base classes for all plugins.

@author: Eitan Isaacson
@organization: IBM Corporation
@copyright: Copyright (c) 2006, 2007 IBM Corporation
@license: BSD

All rights reserved. This program and the accompanying materials are made 
available under the terms of the BSD which accompanies this distribution, and 
is available at U{http://www.opensource.org/licenses/bsd-license.php}
'''

import gtk
from tools import Tools

class Plugin(Tools):
  def __init__(self, node):
    self.node = node
    self.node.connect('accessible_changed', self._onAccChanged)
    self.acc = None
  def init(self):
    pass
  def close(self):
    pass
  def _onAccChanged(self, node, acc):
    self.acc = acc
    self.onAccChanged(acc)
  def onAccChanged(self, acc):
    pass
  

class ViewportPlugin(Plugin, gtk.Viewport):
  def __init__(self, node):
    gtk.Viewport.__init__(self)
    Plugin.__init__(self, node)
    self.set_shadow_type(gtk.SHADOW_NONE)

class ConsolePlugin(Plugin, gtk.TextView):
  def __init__(self, node):
    gtk.TextView.__init__(self)
    Plugin.__init__(self, node)
    self.set_editable(False)
    self.set_cursor_visible(False)
    text_buffer = self.get_buffer()
    self.mark = text_buffer.create_mark('scroll_mark', 
                                        text_buffer.get_end_iter(),
                                        False)
  def appendText(self, text):
    text_buffer = self.get_buffer()
    text_buffer.insert(text_buffer.get_end_iter(), text)
    self.scroll_mark_onscreen(self.mark)
