'''
Defines a base class having tools common to the core and the plugins.

@author: Eitan Isaacson
@organization: IBM Corporation
@copyright: Copyright (c) 2006, 2007 IBM Corporation
@license: BSD

All rights reserved. This program and the accompanying materials are made 
available under the terms of the BSD which accompanies this distribution, and 
is available at U{http://www.opensource.org/licenses/bsd-license.php}
'''
import os
import pickle

class Tools(object):
  SETTINGS_PATH = os.path.join(os.environ['HOME'],
                               '.accerciser')
  SETTINGS_FILE = 'settings.pickle'
  

  def isMyApp(self, acc):
    if not acc:
      return False
    app = acc.getApplication()
    if not app or not hasattr(app, 'id'):
      return False
    if hasattr(self,'my_app_id'):
      if self.my_app_id == app.id:
        return True
    else:
      if app.description == str(os.getpid()):
        self.my_app_id = app.id
        return True
    return False
  
  def loadSettings(self, section=None):
    layout_fn = os.path.join(self.SETTINGS_PATH, self.SETTINGS_FILE)
    try:
      f = open(layout_fn, 'r')
    except:
      return {}
    try:
      rv = pickle.load(f)
    except:
      rv = {}
    f.close()
    if section is None:
      return rv
    else:
      return rv.get(section)

  def saveSettings(self, section, value):
    print 'saving %s: %s' % (section, value)
    layout_fn = os.path.join(self.SETTINGS_PATH, self.SETTINGS_FILE)
    settings = self.loadSettings()
    settings[section] = value
    try:
      if not os.path.exists(os.path.dirname(layout_fn)):
        os.mkdir(os.path.dirname(layout_fn))
      f = open(layout_fn, 'w')
    except:
      return
    pickle.dump(settings, f)
    f.close()
